@@ -113,7 +113,7 @@ class Predictor:
     def train_helper_mixers(self, train_ds, test_ds):
         from lightwood.mixers.boost.boost import BoostMixer
 
-        boost_mixer = BoostMixer()
+        boost_mixer = BoostMixer(quantiles=CONFIG.QUANTILES)
         boost_mixer.train(train_ds)
 
         # @TODO: IF we add more mixers in the future, add the best on for each column to this map !
@@ -126,7 +126,7 @@ class Predictor:
                 continue
 
             real = list(map(str,test_ds.get_column_original_data(output_column)))
-            predicted =  predictions[output_column]['values']
+            predicted =  predictions[output_column]['predictions']
 
             weight_map = None
             if 'weights' in test_ds.get_column_config(output_column):
@@ -260,6 +260,7 @@ class Predictor:
             except Exception as e:
                 logging.warning(f'Failed to train helper mixers with error: {e}')
 
+
         mixer = mixer_class(best_parameters)
         self._mixer = mixer
 
@@ -427,7 +428,6 @@ class Predictor:
         :param when: a dictionary
         :return: a complete dataframe
         """
-
         if when is not None:
             when_dict = {key: [when[key]] for key in when}
             when_data = pandas.DataFrame(when_dict)
@@ -441,10 +441,9 @@ class Predictor:
             for output_column in main_mixer_predictions:
                 if self._helper_mixers is not None and output_column in self._helper_mixers:
                     if self._helper_mixers[output_column]['accuracy'] > 1.00 * self.train_accuracy[output_column]['value']:
-                        helper_mixer_predictions = self._helper_mixers[output_column]['model'].predict(when_data_ds, output_column)
-                        main_mixer_predictions[output_column] = {'predictions': list(helper_mixer_predictions[output_column]['values'])}
-                        if 'confidences' in helper_mixer_predictions[output_column] and helper_mixer_predictions[output_column]['confidences'] is not None:
-                            main_mixer_predictions[output_column]['confidences'] = list(helper_mixer_predictions[output_column]['confidences'])
+                        helper_mixer_predictions = self._helper_mixers[output_column]['model'].predict(when_data_ds, [output_column])
+
+                        main_mixer_predictions[output_column] = helper_mixer_predictions[output_column]
 
         return main_mixer_predictions
 
